responsive_cloud_image library

A CDN-agnostic responsive image loader for Flutter.

This library automatically reads layout constraints and screen density to request optimized image sizes from cloud storage providers and CDNs.

Classes

CloudUrlAdapter
A utility adapter to format original image URLs into optimized CDN URLs.
ResponsiveCloudImage
A widget that dynamically resizes image requests based on layout bounds.

Enums

CloudProvider
Supported cloud storage and CDN providers.