CloudProvider enum
Supported cloud storage and CDN providers.
Values
- supabase → const CloudProvider
-
Supabase Storage dynamic image resizing.
- appwrite → const CloudProvider
-
Appwrite Storage dynamic image resizing.
- cloudinary → const CloudProvider
-
Cloudinary image delivery network.
- imgix → const CloudProvider
-
Imgix image processing CDN.
- unsplash → const CloudProvider
-
Unsplash dynamic image delivery.
- shopify → const CloudProvider
-
Shopify storefront CDN.
- sanity → const CloudProvider
-
Sanity.io Content Lake CDN.
- custom → const CloudProvider
-
Custom user-defined image resizing scheme.
- generic → const CloudProvider
-
Generic fallback (original unaltered URL).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CloudProvider> - A constant List of the values in this enum, in order of their declaration.